@@ -2,7 +2,7 @@ from collections import deque
 from typing import Callable, Deque
 
 import sparklines
-from rich.console import RenderGroup
+from rich.console import RenderableType, RenderGroup
 from rich.padding import Padding
 from rich.panel import Panel
 from rich.text import Text
@@ -17,7 +17,7 @@ class Graph(Panel):
         label,
         get_value: Callable[[], int],
         colours=("red1", "orange1", "yellow1", "green"),
-    ):
+    ) -> None:
         self.queue = deque([0] * self.length, maxlen=self.length)
         self.label = label
         self.colours = colours
@@ -27,22 +27,22 @@ class Graph(Panel):
             self.rerender(), title=f"{label}: [blue]?[/]", width=self.length + 4,
         )
 
-    def rerender(self):
+    def rerender(self) -> RenderableType:
         lines = [
             Text(line, style=colour)
             for colour, line in zip(
                 self.colours,
                 sparklines.sparklines(
-                    self.q, num_lines=len(self.colours), minimum=0, maximum=20
+                    self.queue, num_lines=len(self.colours), minimum=0, maximum=20
                 ),
             )
         ]
         return Padding(RenderGroup(*lines), 1)
 
-    def update(self):
+    def update(self) -> None:
         used = self.get_value()
 
-        self.q.extend([max(0, used if used != "?" else 0)])
+        self.queue.extend([max(0, used if used != "?" else 0)])
 
         self.title = f"{self.label}: [blue]{used}[/]"
         self.renderable = self.rerender()
